package com.github.bluesbruce.spring.mqttService.consumer;

import com.github.bluesbruce.spring.service.MqttLiveHandle;
import com.github.bluesbruce.spring.utils.SpringUtil;
import lombok.extern.slf4j.Slf4j;
import org.eclipse.paho.client.mqttv3.IMqttDeliveryToken;
import org.eclipse.paho.client.mqttv3.MqttCallback;
import org.eclipse.paho.client.mqttv3.MqttMessage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.ObjectUtils;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

@Slf4j
@Component
public class MqttConsumerCallBack implements MqttCallback {

    @Autowired
    private MqttLiveHandle mqttLiveHandle;
/**
 * 客户端断开连接的回调
 */
    @Override
    public void connectionLost(Throwable throwable) {
        System.out.println("与服务器断开连接，可重连");
        /*MqttProviderConfig client = SpringUtil.getBean(MqttProviderConfig.class);
        System.out.println(client.isconnect());
        if (!client.isconnect()) {
            client.connect();
            System.out.println("重连成功！");
        }*/
    }

    DateFormat bf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    /**
     * 消息到达的回调
     */
    @Override
    public void messageArrived(String topic, MqttMessage message) throws Exception {
        try {
            log.info(String.format("接收消息主题 : %s", topic) + "-" + bf.format(new Date()));
            log.info(String.format("接收消息Qos : %d", message.getQos()));
            log.info(String.format("接收消息内容 : %s", new String(message.getPayload())));
            log.info(String.format("接收消息retained : %b", message.isRetained()));
            if (topic.contains("/rtmp/live")||topic.contains("/data/DroneBMS")){
                if (ObjectUtils.isEmpty(mqttLiveHandle)){
                    mqttLiveHandle = SpringUtil.getBean(MqttLiveHandle.class);
                }
                mqttLiveHandle.handleLive(topic,message);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 消息发布成功的回调
     */
    @Override
    public void deliveryComplete(IMqttDeliveryToken iMqttDeliveryToken) {

    }





}

