package com.github.bluesbruce.spring.web;


import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.bluesbruce.ffch.data.CommandTasker;
import com.github.bluesbruce.ffch.handler.DefaultOutHandlerMethod;
import com.github.bluesbruce.spring.config.CmdParam;
import com.github.bluesbruce.spring.service.RtmpLiveService;
import lombok.extern.slf4j.Slf4j;
import org.h2.util.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

@Controller
@Slf4j
public class IndexController {

    @Resource
    private ObjectMapper objectMapper;
    @Autowired
    RtmpLiveService rtmpLiveService;
    @RequestMapping("/status")
    @ResponseBody
    public String index() {
        JSONObject jsonObject  = new JSONObject();
        try {
            int status = rtmpLiveService.status;
            if(rtmpLiveService.manager.queryAll().size()>0){
                Collection<CommandTasker> list =  rtmpLiveService.manager.queryAll();
                Iterator<CommandTasker> commandTaskerIterator = list.iterator();
                CommandTasker s = commandTaskerIterator.next();
                jsonObject.put("name",s.getId());
                jsonObject.put("cmd",s.getCommand().split("bin/")[1]);
            };
            jsonObject.put("msg",status==0?"空闲":"推流中");
            jsonObject.put("status",status);
            return objectMapper.writeValueAsString(jsonObject);
        } catch (Exception e) {
            e.printStackTrace();
            return "失败";
        }
    }


    @RequestMapping("/config")
    @ResponseBody
    public String config() {
        JSONObject jsonObject  = new JSONObject();
        try {
            CmdParam cmdParam  = rtmpLiveService.cmdParam;
            jsonObject.put("pushUrl",cmdParam.getPlayUrl());
            jsonObject.put("playUrl",cmdParam.getPlayUrl());
            return objectMapper.writeValueAsString(jsonObject);
        } catch (Exception e) {
            e.printStackTrace();
            return "失败";
        }
    }

    @RequestMapping("/start")
    @ResponseBody
    public String start() {
        try {
            log.info("http发送重启推流");
            rtmpLiveService.stopRtmp();
            //启动线程
            Thread thread = new Thread(new Runnable() {
                public void run() {
                    try {
                        startPush();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
            thread.start();
            return objectMapper.writeValueAsString("success");
        } catch (Exception e) {
            e.printStackTrace();
            return "失败";
        }
    }

    private void startPush() {
        try {
            rtmpLiveService.pushServer("restart");
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    @RequestMapping("/stop")
    @ResponseBody
    public String stop() {
        try {
            log.info("http发送停止推流");
            rtmpLiveService.stopRtmp();
            return objectMapper.writeValueAsString("success");
        } catch (Exception e) {
            e.printStackTrace();
            return "失败";
        }
    }
}
